@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -82,6 +78,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "cch", "atsam" },
             { "mwr", "marvar\u00ed" },
             { "Zsye", "emoji-t\u00e1kn" },
+            { "ccp", "tsjakma" },
             { "egy", "fornegypska" },
             { "raj", "rajastan\u00ed" },
             { "tem", "t\u00edmne" },
@@ -96,7 +93,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "nl_BE", "fl\u00e6mska" },
             { "AF", "Afganistan" },
             { "AG", "Ant\u00edgva og Barb\u00fada" },
-            { "type.ca.ethiopic", "E\u00fe\u00ed\u00f3p\u00edskt dagatal" },
+            { "type.ca.ethiopic", "E\u00fe\u00ed\u00f3p\u00edskt t\u00edmatal" },
             { "AI", "Angvilla" },
             { "key.tz", "T\u00edmabelti" },
             { "AL", "Alban\u00eda" },
@@ -138,7 +135,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "BW", "Botsvana" },
             { "BY", "Hv\u00edta-R\u00fassland" },
             { "BZ", "Bel\u00eds" },
-            { "type.ca.persian", "Persneskt dagatal" },
+            { "type.ca.persian", "Persneskt t\u00edmatal" },
             { "type.nu.hebr", "Hebreskir t\u00f6lustafir" },
             { "CA", "Kanada" },
             { "CC", "K\u00f3koseyjar (Keeling)" },
@@ -208,7 +205,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "ET", "E\u00fe\u00ed\u00f3p\u00eda" },
             { "EU", "Evr\u00f3pusambandi\u00f0" },
             { "elx", "elam\u00edt" },
-            { "type.ca.gregorian", "Gregor\u00edskt dagatal" },
+            { "type.ca.gregorian", "Gregor\u00edskt t\u00edmatal" },
             { "EZ", "Evrusv\u00e6\u00f0i\u00f0" },
             { "chy", "sjeyen" },
             { "type.nu.gujr", "Gujarati-t\u00f6lur" },
@@ -223,7 +220,6 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "FR", "Frakkland" },
             { "tkl", "t\u00f3kel\u00e1ska" },
             { "grb", "gerb\u00f3" },
-            { "root", "r\u00f3t" },
             { "type.ca.indian", "indverskt dagatal" },
             { "grc", "forngr\u00edska" },
             { "GA", "Gabon" },
@@ -265,7 +261,6 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "HU", "Ungverjaland" },
             { "tmh", "tamasjek" },
             { "IC", "Kanar\u00edeyjar" },
-            { "nan", "nan" },
             { "ID", "Ind\u00f3nes\u00eda" },
             { "peo", "fornpersneska" },
             { "IE", "\u00cdrland" },
@@ -285,7 +280,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "type.nu.thai", "T\u00e6lenskar t\u00f6lur" },
             { "type.nu.beng", "Bengalskar t\u00f6lur" },
             { "JE", "Jersey" },
-            { "type.ca.islamic", "\u00cdslamskt dagatal" },
+            { "type.ca.islamic", "\u00cdslamskt t\u00edmatal" },
             { "JM", "Jama\u00edka" },
             { "Beng", "bengalskt" },
             { "JO", "J\u00f3rdan\u00eda" },
@@ -296,7 +291,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "type.nu.knda", "Kannada-t\u00f6lur" },
             { "de_CH", "svissnesk h\u00e1\u00fe\u00fdska" },
             { "type.co.phonetic", "Hlj\u00f3\u00f0fr\u00e6\u00f0ileg r\u00f6\u00f0" },
-            { "type.ca.buddhist", "B\u00fadd\u00edskt dagatal" },
+            { "type.ca.buddhist", "B\u00fadd\u00edskt t\u00edmatal" },
             { "KE", "Ken\u00eda" },
             { "419", "R\u00f3manska Amer\u00edka" },
             { "KG", "Kirgistan" },
@@ -340,7 +335,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "MC", "M\u00f3nak\u00f3" },
             { "MD", "Mold\u00f3va" },
             { "ME", "Svartfjallaland" },
-            { "MF", "St. Martin" },
+            { "MF", "Saint-Martin" },
             { "lam", "lamba" },
             { "MG", "Madagaskar" },
             { "MH", "Marshalleyjar" },
@@ -364,12 +359,12 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "MV", "Mald\u00edveyjar" },
             { "MW", "Malav\u00ed" },
             { "MX", "Mex\u00edk\u00f3" },
-            { "type.ca.japanese", "Japanskt dagatal" },
+            { "type.ca.japanese", "Japanskt t\u00edmatal" },
             { "MY", "Malas\u00eda" },
             { "MZ", "M\u00f3samb\u00edk" },
             { "NA", "Namib\u00eda" },
             { "202", "Afr\u00edka sunnan Sahara" },
-            { "type.ca.hebrew", "Hebreskt dagatal" },
+            { "type.ca.hebrew", "Hebreskt t\u00edmatal" },
             { "type.co.dictionary", "Or\u00f0ab\u00f3karr\u00f6\u00f0" },
             { "NC", "N\u00fdja-Kaled\u00f3n\u00eda" },
             { "NE", "N\u00edger" },
@@ -464,7 +459,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "SS", "Su\u00f0ur-S\u00fadan" },
             { "ST", "Sa\u00f3 T\u00f3me og Prins\u00edpe" },
             { "SV", "El Salvador" },
-            { "SX", "Sankti Martin" },
+            { "SX", "Sint Maarten" },
             { "SY", "S\u00fdrland" },
             { "yao", "ja\u00f3" },
             { "SZ", "Svas\u00edland" },
@@ -480,7 +475,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "TF", "Fr\u00f6nsku su\u00f0l\u00e6gu landsv\u00e6\u00f0in" },
             { "TG", "T\u00f3g\u00f3" },
             { "TH", "Ta\u00edland" },
-            { "TJ", "Tadsjikistan" },
+            { "TJ", "Tads\u00edkistan" },
             { "029", "Kar\u00edbahafi\u00f0" },
             { "TK", "T\u00f3kel\u00e1" },
             { "TL", "T\u00edmor-Leste" },
@@ -506,7 +501,6 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "hai", "ha\u00edda" },
             { "035", "Su\u00f0austur-As\u00eda" },
             { "UG", "\u00daganda" },
-            { "hak", "hak" },
             { "type.co.pinyin", "Pinyin-r\u00f6\u00f0un" },
             { "039", "Su\u00f0ur-Evr\u00f3pa" },
             { "Sinh", "sinhala" },
@@ -545,7 +539,9 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "WS", "Sam\u00f3a" },
             { "wal", "volayatta" },
             { "was", "vasj\u00f3" },
+            { "XA", "gervihreimur" },
             { "war", "vara\u00ed" },
+            { "XB", "gervista\u00f0ur" },
             { "awa", "avad\u00ed" },
             { "061", "P\u00f3l\u00fdnes\u00eda" },
             { "XK", "K\u00f3s\u00f3v\u00f3" },
@@ -568,7 +564,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "ZW", "Simbabve" },
             { "ZZ", "\u00d3\u00feekkt sv\u00e6\u00f0i" },
             { "type.ms.metric", "Metrakerfi" },
-            { "type.ca.iso8601", "ISO-8601 dagatal" },
+            { "type.ca.iso8601", "ISO-8601 t\u00edmatal" },
             { "lol", "mong\u00f3" },
             { "nso", "nor\u00f0urs\u00f3t\u00f3" },
             { "type.nu.telu", "Tel\u00fag\u00fa-t\u00f6lur" },
@@ -683,7 +679,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "es_419", "r\u00f3m\u00f6nsk-amer\u00edsk sp\u00e6nska" },
             { "dz", "dsongka" },
             { "bez", "bena" },
-            { "type.ca.chinese", "K\u00ednverskt dagatal" },
+            { "type.ca.chinese", "K\u00ednversk t\u00edmatal" },
             { "dje", "zarma" },
             { "type.nu.grek", "Gr\u00edskir t\u00f6lustafir" },
             { "ee", "ewe" },
@@ -707,7 +703,6 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "type.nu.latn", "Vestr\u00e6nar t\u00f6lur" },
             { "Hant", "hef\u00f0bundi\u00f0" },
             { "ff", "f\u00fala" },
-            { "hsn", "hsn" },
             { "fi", "finnska" },
             { "fj", "f\u00eddjeyska" },
             { "fon", "f\u00f3n" },
@@ -721,7 +716,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "fy", "vesturfr\u00edsneska" },
             { "ga", "\u00edrska" },
             { "gd", "skosk gel\u00edska" },
-            { "gl", "gal\u00edanska" },
+            { "gl", "galis\u00edska" },
             { "gn", "gvaran\u00ed" },
             { "bho", "bojp\u00far\u00ed" },
             { "und", "\u00f3\u00feekkt tungum\u00e1l" },
@@ -741,7 +736,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "hy", "armenska" },
             { "hz", "herer\u00f3" },
             { "frc", "cajun-franska" },
-            { "ia", "al\u00fej\u00f3\u00f0atunga" },
+            { "ia", "interlingua" },
             { "Jamo", "jamo" },
             { "id", "ind\u00f3nes\u00edska" },
             { "type.nu.tibt", "T\u00edbeskir t\u00f6lustafir" },
@@ -770,7 +765,6 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "ka", "georg\u00edska" },
             { "bla", "siksika" },
             { "mak", "makasar" },
-            { "wuu", "wuu" },
             { "sms", "skoltesam\u00edska" },
             { "man", "manding\u00f3" },
             { "kg", "kong\u00f3ska" },
@@ -813,7 +807,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "mr", "marat\u00ed" },
             { "ms", "mala\u00edska" },
             { "mt", "maltneska" },
-            { "my", "burmneska" },
+            { "my", "b\u00farmneska" },
             { "Armn", "armenskt" },
             { "mdf", "moksa" },
             { "dsb", "l\u00e1gsorbneska" },
@@ -830,7 +824,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "nr", "su\u00f0urndebele" },
             { "nv", "navah\u00f3" },
             { "kaa", "karakalpak" },
-            { "ny", "njanja; s\u00edsjeva; sjeva" },
+            { "ny", "n\u00fdanja" },
             { "kac", "kas\u00edn" },
             { "kab", "kab\u00edle" },
             { "oc", "oks\u00edtan\u00edska" },
@@ -853,7 +847,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "pi", "pal\u00ed" },
             { "pl", "p\u00f3lska" },
             { "dum", "mi\u00f0hollenska" },
-            { "type.ca.dangi", "Dangi dagatal" },
+            { "type.ca.dangi", "Dangi t\u00edmatal" },
             { "ps", "past\u00fa" },
             { "pt", "port\u00fagalska" },
             { "mga", "mi\u00f0\u00edrska" },
@@ -863,7 +857,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "mgh", "makhuwa-meetto" },
             { "key.cf", "Gjaldmi\u00f0ilssni\u00f0" },
             { "bra", "bra\u00ed" },
-            { "key.ca", "Dagatal" },
+            { "key.ca", "T\u00edmatal" },
             { "Laoo", "lao" },
             { "mgo", "meta\u2019" },
             { "type.hc.h23", "24 t\u00edma kerfi (0\u201323)" },
@@ -961,7 +955,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "kha", "kas\u00ed" },
             { "nds_NL", "l\u00e1gsaxneska" },
             { "ve", "venda" },
-            { "type.ca.roc", "Minguo dagatal" },
+            { "type.ca.roc", "Minguo t\u00edmatal" },
             { "vi", "v\u00edetnamska" },
             { "kho", "kotaska" },
             { "khq", "koyra chiini" },
@@ -1033,6 +1027,7 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "type.nu.tamldec", "Tam\u00edlskar t\u00f6lur" },
             { "krc", "karasa\u00edbalkar" },
             { "inh", "ing\u00fas" },
+            { "fa_AF", "dar\u00ed" },
             { "krl", "kar\u00e9lska" },
             { "efi", "ef\u00edk" },
             { "key.nu", "T\u00f6lur" },
