@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -70,77 +66,69 @@ import sun.util.resources.TimeZoneNamesBundle;
 public class TimeZoneNames_en_AU extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] Iran = new String[] {
-               "Iran Standard Time",
-               "IRST",
-               "Iran Daylight Time",
-               "IRDT",
-               "Iran Time",
-               "IRT",
+        final String[] Cook = new String[] {
+               "Cook Island Standard Time",
+               "",
+               "Cook Island Summer Time",
+               "",
+               "Cook Island Time",
+               "",
             };
-        final String[] Moscow = new String[] {
-               "Moscow Standard Time",
-               "MSK",
-               "Moscow Daylight Time",
-               "MSD",
-               "Moscow Time",
-               "MT",
+        final String[] China = new String[] {
+               "China Standard Time",
+               "",
+               "China Summer Time",
+               "",
+               "China Time",
+               "",
             };
         final String[] Japan = new String[] {
                "Japan Standard Time",
-               "JST",
+               "",
                "Japan Summer Time",
-               "JDT",
+               "",
                "Japan Time",
-               "JT",
-            };
-        final String[] Taipei = new String[] {
-               "Taipei Standard Time",
-               "CST",
-               "Taipei Summer Time",
-               "CDT",
-               "Taipei Time",
-               "CT",
-            };
-        final String[] Israel = new String[] {
-               "Israel Standard Time",
-               "IST",
-               "Israel Daylight Time",
-               "IDT",
-               "Israel Time",
-               "IT",
-            };
-        final String[] Australia_CentralWestern = new String[] {
-               "Australian Central Western Standard Time",
-               "ACWST",
-               "Australian Central Western Daylight Time",
-               "ACWDT",
-               "Australian Central Western Time",
-               "ACWT",
+               "",
             };
         final String[] Korea = new String[] {
                "Korean Standard Time",
-               "KST",
+               "",
                "Korean Summer Time",
-               "KDT",
+               "",
                "Korea Time",
-               "KT",
+               "",
             };
-        final String[] Australia_Western = new String[] {
-               "Australian Western Standard Time",
-               "AWST",
-               "Australian Western Daylight Time",
-               "AWDT",
-               "Australian Western Time",
-               "AWT",
+        final String[] Samoa = new String[] {
+               "Samoa Standard Time",
+               "",
+               "Samoa Summer Time",
+               "",
+               "Samoa Time",
+               "",
             };
-        final String[] Australia_Central = new String[] {
-               "Australian Central Standard Time",
-               "ACST",
-               "Australian Central Daylight Time",
-               "ACDT",
-               "Australian Central Time",
-               "ACT",
+        final String[] Moscow = new String[] {
+               "Moscow Standard Time",
+               "",
+               "Moscow Daylight Time",
+               "",
+               "Moscow Time",
+               "",
+            };
+        final String[] Taipei = new String[] {
+               "Taipei Standard Time",
+               "",
+               "Taipei Summer Time",
+               "",
+               "Taipei Time",
+               "",
+            };
+        final String[] Arabian = new String[] {
+               "Arabia Standard Time",
+               "",
+               "Arabia Daylight Time",
+               "",
+               "Arabia Time",
+               "",
             };
         final String[] Lord_Howe = new String[] {
                "Lord Howe Standard Time",
@@ -150,6 +138,14 @@ public class TimeZoneNames_en_AU extends TimeZoneNamesBundle {
                "Lord Howe Time",
                "LHT",
             };
+        final String[] EMPTY_ZONE = new String[] {
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] New_Zealand = new String[] {
                "New Zealand Standard Time",
                "NZST",
@@ -158,6 +154,22 @@ public class TimeZoneNames_en_AU extends TimeZoneNamesBundle {
                "New Zealand Time",
                "NZT",
             };
+        final String[] Africa_Eastern = new String[] {
+               "Eastern Africa Time",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Australia_Central = new String[] {
+               "Australian Central Standard Time",
+               "ACST",
+               "Australian Central Daylight Time",
+               "ACDT",
+               "Australian Central Time",
+               "ACT",
+            };
         final String[] Australia_Eastern = new String[] {
                "Australian Eastern Standard Time",
                "AEST",
@@ -166,250 +178,77 @@ public class TimeZoneNames_en_AU extends TimeZoneNamesBundle {
                "Australian Eastern Time",
                "AET",
             };
-        final String[] Arabian = new String[] {
-               "Arabia Standard Time",
-               "AST",
-               "Arabia Daylight Time",
-               "ADT",
-               "Arabia Time",
-               "AT",
+        final String[] Australia_Western = new String[] {
+               "Australian Western Standard Time",
+               "AWST",
+               "Australian Western Daylight Time",
+               "AWDT",
+               "Australian Western Time",
+               "AWT",
             };
-        final String[] Africa_Eastern = new String[] {
-               "Eastern Africa Time",
-               "EAT",
-               "Eastern African Summer Time",
-               "EAST",
-               "Eastern Africa Time",
-               "EAT",
-            };
-        final String[] Europe_Eastern = new String[] {
-               "Eastern European Standard Time",
-               "EET",
-               "Eastern European Summer Time",
-               "EEST",
-               "Eastern European Time",
-               "EET",
-            };
-        final String[] Samoa = new String[] {
-               "Samoa Standard Time",
-               "SST",
-               "Samoa Summer Time",
-               "SDT",
-               "Samoa Time",
-               "ST",
-            };
-        final String[] China = new String[] {
-               "China Standard Time",
-               "CST",
-               "China Summer Time",
-               "CDT",
-               "China Time",
-               "CT",
-            };
-        final String[] Amazon = new String[] {
-               "Amazon Standard Time",
-               "AMT",
-               "Amazon Summer Time",
-               "AMST",
-               "Amazon Time",
-               "AMT",
-            };
-        final String[] Cook = new String[] {
-               "Cook Island Standard Time",
-               "CKT",
-               "Cook Island Summer Time",
-               "CKHST",
-               "Cook Island Time",
-               "CKT",
+        final String[] Australia_CentralWestern = new String[] {
+               "Australian Central Western Standard Time",
+               "ACWST",
+               "Australian Central Western Daylight Time",
+               "ACWDT",
+               "Australian Central Western Time",
+               "ACWT",
             };
         final Object[][] data = new Object[][] {
-            { "Africa/Casablanca",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
-            { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
-            { "UTC",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
+            { "UTC", EMPTY_ZONE },
+            { "ACT", Australia_Central },
+            { "AET", Australia_Eastern },
+            { "CTT", China },
+            { "EAT", Africa_Eastern },
+            { "JST", Japan },
+            { "NST", New_Zealand },
             { "Asia/Aden", Arabian },
-            { "America/Cuiaba", Amazon },
-            { "Africa/Nairobi", Africa_Eastern },
-            { "Africa/El_Aaiun",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Africa/Cairo", Europe_Eastern },
-            { "Pacific/Pago_Pago", Samoa },
-            { "Europe/Moscow", Moscow },
-            { "Pacific/Rarotonga", Cook },
-            { "Australia/Hobart", Australia_Eastern },
-            { "Europe/Chisinau", Europe_Eastern },
-            { "Asia/Baghdad", Arabian },
-            { "Australia/Eucla", Australia_CentralWestern },
-            { "America/Porto_Velho", Amazon },
-            { "Europe/Helsinki", Europe_Eastern },
-            { "Asia/Beirut", Europe_Eastern },
-            { "Pacific/Bougainville",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Europe/Tallinn", Europe_Eastern },
-            { "Asia/Damascus", Europe_Eastern },
-            { "Asia/Tehran", Iran },
-            { "Europe/Zaporozhye", Europe_Eastern },
-            { "Europe/Astrakhan",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Asia/Taipei", Taipei },
-            { "Africa/Juba", Africa_Eastern },
-            { "America/Campo_Grande", Amazon },
-            { "Antarctica/South_Pole", New_Zealand },
-            { "Pacific/Midway", Samoa },
-            { "Africa/Dar_es_Salaam", Africa_Eastern },
-            { "Antarctica/Palmer",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Africa/Addis_Ababa", Africa_Eastern },
-            { "Australia/Adelaide", Australia_Central },
-            { "Europe/Uzhgorod", Europe_Eastern },
-            { "Africa/Djibouti", Africa_Eastern },
-            { "Europe/Simferopol", Moscow },
-            { "Europe/Sofia", Europe_Eastern },
-            { "America/Punta_Arenas",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Africa/Tripoli", Europe_Eastern },
-            { "Indian/Comoro", Africa_Eastern },
-            { "Asia/Nicosia", Europe_Eastern },
-            { "Europe/Kaliningrad", Europe_Eastern },
-            { "Asia/Riyadh", Arabian },
-            { "Asia/Pyongyang", Korea },
-            { "Asia/Harbin", China },
-            { "America/Boa_Vista", Amazon },
-            { "Africa/Mogadishu", Africa_Eastern },
-            { "Asia/Gaza", Europe_Eastern },
-            { "Australia/Perth", Australia_Western },
-            { "Australia/Darwin", Australia_Central },
-            { "Asia/Famagusta",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Asia/Kuwait", Arabian },
-            { "Antarctica/McMurdo", New_Zealand },
-            { "America/Manaus", Amazon },
-            { "Antarctica/Casey", Australia_Western },
             { "Asia/Macau", China },
-            { "timezone.excity.Asia/Rangoon", "Rangoon" },
-            { "Africa/Asmera", Africa_Eastern },
-            { "Europe/Ulyanovsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Africa/Kampala", Africa_Eastern },
-            { "Australia/Broken_Hill", Australia_Central },
-            { "Europe/Minsk", Moscow },
-            { "Pacific/Auckland", New_Zealand },
-            { "Europe/Riga", Europe_Eastern },
             { "Asia/Qatar", Arabian },
-            { "Europe/Kiev", Europe_Eastern },
-            { "Asia/Hebron", Europe_Eastern },
-            { "timezone.excity.America/St_Barthelemy", "St Barth\u00e9lemy" },
-            { "Asia/Srednekolymsk",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
-            { "Australia/Currie", Australia_Eastern },
-            { "Australia/Melbourne", Australia_Eastern },
-            { "Europe/Mariehamn", Europe_Eastern },
-            { "Asia/Bahrain", Arabian },
-            { "Europe/Vilnius", Europe_Eastern },
-            { "Asia/Chongqing", China },
-            { "Europe/Saratov",
-                new String[] {
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                    "",
-                }
-            },
             { "Asia/Seoul", Korea },
-            { "Asia/Amman", Europe_Eastern },
-            { "Australia/Sydney", Australia_Eastern },
-            { "Australia/Lord_Howe", Lord_Howe },
-            { "Indian/Antananarivo", Africa_Eastern },
-            { "Australia/Lindeman", Australia_Eastern },
-            { "Australia/Brisbane", Australia_Eastern },
+            { "Asia/Harbin", China },
+            { "Asia/Kuwait", Arabian },
+            { "Asia/Riyadh", Arabian },
+            { "Asia/Taipei", Taipei },
+            { "Asia/Baghdad", Arabian },
+            { "Asia/Bahrain", Arabian },
+            { "Europe/Minsk", Moscow },
+            { "Africa/Asmera", Africa_Eastern },
+            { "Europe/Moscow", Moscow },
+            { "Indian/Comoro", Africa_Eastern },
+            { "Africa/Kampala", Africa_Eastern },
+            { "Africa/Nairobi", Africa_Eastern },
+            { "Asia/Chongqing", China },
+            { "Asia/Pyongyang", Korea },
             { "Indian/Mayotte", Africa_Eastern },
-            { "Europe/Athens", Europe_Eastern },
+            { "Pacific/Midway", Samoa },
+            { "Africa/Djibouti", Africa_Eastern },
+            { "Australia/Eucla", Australia_CentralWestern },
+            { "Australia/Perth", Australia_Western },
+            { "Africa/Mogadishu", Africa_Eastern },
+            { "Australia/Currie", Australia_Eastern },
+            { "Australia/Darwin", Australia_Central },
+            { "Australia/Hobart", Australia_Eastern },
+            { "Australia/Sydney", Australia_Eastern },
+            { "Pacific/Auckland", New_Zealand },
+            { "Europe/Simferopol", Moscow },
+            { "Pacific/Pago_Pago", Samoa },
+            { "Pacific/Rarotonga", Cook },
+            { "Africa/Addis_Ababa", Africa_Eastern },
+            { "Antarctica/McMurdo", New_Zealand },
+            { "Australia/Adelaide", Australia_Central },
+            { "Australia/Brisbane", Australia_Eastern },
+            { "Australia/Lindeman", Australia_Eastern },
+            { "Australia/Lord_Howe", Lord_Howe },
+            { "Australia/Melbourne", Australia_Eastern },
+            { "Indian/Antananarivo", Africa_Eastern },
+            { "Africa/Dar_es_Salaam", Africa_Eastern },
+            { "Antarctica/Macquarie", Australia_Eastern },
+            { "Antarctica/South_Pole", New_Zealand },
+            { "Australia/Broken_Hill", Australia_Central },
+            { "timezone.excity.Pacific/Johnston", "Johnston" },
         };
         return data;
     }
